//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	Color: A class representing a color.
//
//	DESCRIPTION:
//		A class that represents a color composed of a red/green/blue
//		component.
//
//	CHANGE HISTORY:
//		MB, 1999-??-??: 1.0.0: - first version
//
//	AUTHORS:
//		M. Beijersbergen (MB)
//		U. Lammers (UL), Mon Jul 17 13:46:09 MET DST 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/task_devel/packages/xcolorcod/src/Color.h,v 1.3 2000/07/19 12:57:36 ulammers Exp $
//
#ifndef COLOR_H
#define COLOR_H

#include <iostream>

class Color {
public:
	Color(int r=0, int g=0, int b=0) : red(r), green(g), blue(b) {}

	Color& operator+=(const Color& c) {
		red += c.red; green += c.green; blue += c.blue;
		return *this;
	}

	Color& operator-=(const Color& c) {
		red -= c.red; green -= c.green; blue -= c.blue;
		return *this;
	}

	Color& operator*=(double f) {
		red *= f; green *= f; blue *= f;
		return *this;
	}

	inline double &component(unsigned n) {
		if (n==0)
			return red;
		if (n==1)
			return green;
		return blue;
	}

	double red, green, blue;

	static Color black;
	static Color white;
};

inline ostream& operator<<(ostream& os, const Color& c)
{ return os << int(c.red) << ' ' << int(c.green) << ' ' << int(c.blue); }

inline Color operator+(const Color& c1, const Color& c2) {
	Color r = c1;
	r += c2;
	return r;
}

inline Color operator-(const Color& c1, const Color& c2) {
	Color r = c1;
	r -= c2;
	return r;
}

inline Color operator*(double f, const Color& c) {
	Color r = c;
	r *= f;
	return r;
}

#endif
