//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	ColorImage: A class representing a color image
//
//	DESCRIPTION:
//		A class that represents a color image; offers methods to manipulate
//		the image;
//
//	CHANGE HISTORY:
//		MB, 1999-??-??: 1.0.0: - first version
//
//	AUTHORS:
//		M. Beijersbergen (MB)
//		U. Lammers (UL), Mon Jul 17 13:46:09 MET DST 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/task_devel/packages/xcolorcod/src/ColorImage.h,v 1.3 2000/07/19 12:57:36 ulammers Exp $
//
#ifndef COLORIMAGE_H
#define COLORIMAGE_H

#include <string>
#include "Dal.h"
#include "Color.h"

class ColorImage {
public:
	ColorImage(int nx = 0, int ny = 0);
    ~ColorImage();

	void size(int nx, int ny);

	double max() const;

	Color& operator()(int ix, int iy);
	const Color& operator()(int ix, int iy) const;

	void normalize(double max);

	void log(double decades);

	void writePPM(ostream& os) const;

	void writeDataSet(const string &name, bool asCube = false);

private:
	Color	*_pixels;
	int		_nx, _ny;

	void writeAsRGBarrays(DataSet *set);
	void writeAsDataCube(DataSet *set);
};

#endif
